@@ -664,7 +664,48 @@ QString ConstraintActivityPreferredRoom::getDescription(Rules& r){
 
 	QString s="Activity preferred room"; s+=", ";
 	s+=QObject::tr("WP:%1\%").arg(this->weightPercentage);s+=", ";
-	s+=QObject::tr("A:%1").arg(this->activityId);s+=", ";
+	s+=QObject::tr("A:%1").arg(this->activityId);
+
+	//* write the teachers, subject and students sets
+	int ai;
+	for(ai=0; ai<r.activitiesList.size(); ai++)
+		if(r.activitiesList[ai]->id==this->activityId)
+			break;
+	s+=" (";	
+	if(ai==r.activitiesList.size()){
+		s+=QObject::tr(" Invalid (inexistent) activity id for constraint activity preferred room");
+	}
+	else{
+		assert(ai<r.activitiesList.size());
+		s+=QObject::tr("T:");
+		int k=0;
+		foreach(QString ss, r.activitiesList[ai]->teachersNames){
+			if(k>0)
+				s+=",";
+			s+=ss;
+			k++;
+		}
+	
+		s+=QObject::tr(",S:");
+		s+=r.activitiesList[ai]->subjectName;
+	
+		if(r.activitiesList[ai]->subjectTagName!="")
+			s+=QObject::tr(",ST:")+r.activitiesList[ai]->subjectTagName;
+	
+		s+=QObject::tr(",St:");
+		k=0;
+		foreach(QString ss, r.activitiesList[ai]->studentsNames){
+			if(k>0)
+				s+=",";
+			s+=ss;
+			k++;
+		}	
+	}
+	s+=")";
+	//* end section
+
+	s+=", ";
+
 	s+=QObject::tr("R:%1").arg(this->roomName);
 
 	return s;
@@ -677,7 +718,49 @@ QString ConstraintActivityPreferredRoom::getDetailedDescription(Rules& r){
 	QString s=QObject::tr("Space constraint"); s+="\n";
 	s+=QObject::tr("Activity preferred room"); s+="\n";
 	s+=QObject::tr("Weight (percentage)=%1\%").arg(this->weightPercentage);s+="\n";
-	s+=QObject::tr("Activity id=%1").arg(this->activityId);s+="\n";
+	
+	s+=QObject::tr("Activity id=%1").arg(this->activityId);
+	
+	//* write the teachers, subject and students sets
+	int ai;
+	for(ai=0; ai<r.activitiesList.size(); ai++)
+		if(r.activitiesList[ai]->id==this->activityId)
+			break;
+	s+=" (";	
+	if(ai==r.activitiesList.size()){
+		s+=QObject::tr(" Invalid (inexistent) activity id for constraint activity preferred room");
+	}
+	else{
+		assert(ai<r.activitiesList.size());
+		s+=QObject::tr("T:");
+		int k=0;
+		foreach(QString ss, r.activitiesList[ai]->teachersNames){
+			if(k>0)
+				s+=",";
+			s+=ss;
+			k++;
+		}
+	
+		s+=QObject::tr(",S:");
+		s+=r.activitiesList[ai]->subjectName;
+	
+		if(r.activitiesList[ai]->subjectTagName!="")
+			s+=QObject::tr(",ST:")+r.activitiesList[ai]->subjectTagName;
+	
+		s+=QObject::tr(",St:");
+		k=0;
+		foreach(QString ss, r.activitiesList[ai]->studentsNames){
+			if(k>0)
+				s+=",";
+			s+=ss;
+			k++;
+		}	
+	}
+	s+=")";
+	//* end section
+		
+	s+="\n";
+	
 	s+=QObject::tr("Room=%1").arg(this->roomName);s+="\n";
 
 	return s;
@@ -782,10 +865,7 @@ bool ConstraintActivityPreferredRoom::isRelatedToStudentsSet(Rules& r, StudentsS
 
 bool ConstraintActivityPreferredRoom::isRelatedToRoom(Room* r)
 {
-	if(r)
-		;
-
-	return false;
+	return r->name==this->roomName;
 }
 
 /////////////////////////////////////////////////////////////////////////////////////////////////
@@ -858,6 +938,45 @@ QString ConstraintActivityPreferredRooms::getDescription(Rules& r){
 	QString s="Activity preferred rooms"; s+=", ";
 	s+=QObject::tr("WP:%1\%").arg(this->weightPercentage);s+=", ";
 	s+=QObject::tr("A:%1").arg(this->activityId);
+
+	//* write the teachers, subject and students sets
+	int ai;
+	for(ai=0; ai<r.activitiesList.size(); ai++)
+		if(r.activitiesList[ai]->id==this->activityId)
+			break;
+	s+=" (";	
+	if(ai==r.activitiesList.size()){
+		s+=QObject::tr(" Invalid (inexistent) activity id for constraint activity preferred rooms");
+	}
+	else{
+		assert(ai<r.activitiesList.size());
+		s+=QObject::tr("T:");
+		int k=0;
+		foreach(QString ss, r.activitiesList[ai]->teachersNames){
+			if(k>0)
+				s+=",";
+			s+=ss;
+			k++;
+		}
+	
+		s+=QObject::tr(",S:");
+		s+=r.activitiesList[ai]->subjectName;
+	
+		if(r.activitiesList[ai]->subjectTagName!="")
+			s+=QObject::tr(",ST:")+r.activitiesList[ai]->subjectTagName;
+	
+		s+=QObject::tr(",St:");
+		k=0;
+		foreach(QString ss, r.activitiesList[ai]->studentsNames){
+			if(k>0)
+				s+=",";
+			s+=ss;
+			k++;
+		}	
+	}
+	s+=")";
+	//* end section
+
 	for(QStringList::Iterator it=this->roomsNames.begin(); it!=this->roomsNames.end(); it++){
 		s+=", ";
 		s+=QObject::tr("R:%1").arg(*it);
@@ -873,7 +992,49 @@ QString ConstraintActivityPreferredRooms::getDetailedDescription(Rules& r){
 	QString s=QObject::tr("Space constraint"); s+="\n";
 	s+=QObject::tr("Activity preferred rooms"); s+="\n";
 	s+=QObject::tr("Weight (percentage)=%1\%").arg(this->weightPercentage);s+="\n";
-	s+=QObject::tr("Activity id=%1").arg(this->activityId);s+="\n";
+	
+	s+=QObject::tr("Activity id=%1").arg(this->activityId);
+	
+	//* write the teachers, subject and students sets
+	int ai;
+	for(ai=0; ai<r.activitiesList.size(); ai++)
+		if(r.activitiesList[ai]->id==this->activityId)
+			break;
+	s+=" (";	
+	if(ai==r.activitiesList.size()){
+		s+=QObject::tr(" Invalid (inexistent) activity id for constraint activity preferred rooms");
+	}
+	else{
+		assert(ai<r.activitiesList.size());
+		s+=QObject::tr("T:");
+		int k=0;
+		foreach(QString ss, r.activitiesList[ai]->teachersNames){
+			if(k>0)
+				s+=",";
+			s+=ss;
+			k++;
+		}
+	
+		s+=QObject::tr(",S:");
+		s+=r.activitiesList[ai]->subjectName;
+	
+		if(r.activitiesList[ai]->subjectTagName!="")
+			s+=QObject::tr(",ST:")+r.activitiesList[ai]->subjectTagName;
+	
+		s+=QObject::tr(",St:");
+		k=0;
+		foreach(QString ss, r.activitiesList[ai]->studentsNames){
+			if(k>0)
+				s+=",";
+			s+=ss;
+			k++;
+		}	
+	}
+	s+=")";
+	//* end section
+
+	s+="\n";
+	
 	for(QStringList::Iterator it=this->roomsNames.begin(); it!=this->roomsNames.end(); it++){
 		s+=QObject::tr("Room=%1").arg(*it);
 		s+="\n";
@@ -987,10 +1148,7 @@ bool ConstraintActivityPreferredRooms::isRelatedToStudentsSet(Rules& r, Students
 
 bool ConstraintActivityPreferredRooms::isRelatedToRoom(Room* r)
 {
-	if(r)
-		;
-
-	return false;
+	return this->roomsNames.contains(r->name);
 }
 
 /////////////////////////////////////////////////////////////////////////////////////////////////
@@ -1178,10 +1336,7 @@ bool ConstraintSubjectPreferredRoom::isRelatedToStudentsSet(Rules& r, StudentsSe
 
 bool ConstraintSubjectPreferredRoom::isRelatedToRoom(Room* r)
 {
-	if(r)
-		;
-
-	return false;
+	return r->name==this->roomName;
 }
 
 /////////////////////////////////////////////////////////////////////////////////////////////////
@@ -1386,10 +1541,7 @@ bool ConstraintSubjectPreferredRooms::isRelatedToStudentsSet(Rules& r, StudentsS
 
 bool ConstraintSubjectPreferredRooms::isRelatedToRoom(Room* r)
 {
-	if(r)
-		;
-
-	return false;
+	return this->roomsNames.contains(r->name);
 }
 
 //////////////////////////////////////////////////////////////////////////////////////
@@ -1448,7 +1600,7 @@ QString ConstraintSubjectSubjectTagPreferredRoom::getDescription(Rules& r){
 	if(&r!=NULL)
 		;
 
-	QString s="Subject subject tagp referred room"; s+=", ";
+	QString s="Subject subject tag preferred room"; s+=", ";
 	s+=QObject::tr("WP:%1\%").arg(this->weightPercentage);s+=", ";
 	s+=QObject::tr("S:%1").arg(this->subjectName);s+=",";
 	s+=QObject::tr("ST:%1").arg(this->subjectTagName);s+=",";
@@ -1582,10 +1734,7 @@ bool ConstraintSubjectSubjectTagPreferredRoom::isRelatedToStudentsSet(Rules& r,
 
 bool ConstraintSubjectSubjectTagPreferredRoom::isRelatedToRoom(Room* r)
 {
-	if(r)
-		;
-
-	return false;
+	return r->name==this->roomName;
 }
 
 /////////////////////////////////////////////////////////////////////////////////////////////////
@@ -1795,10 +1944,7 @@ bool ConstraintSubjectSubjectTagPreferredRooms::isRelatedToStudentsSet(Rules& r,
 
 bool ConstraintSubjectSubjectTagPreferredRooms::isRelatedToRoom(Room* r)
 {
-	if(r)
-		;
-
-	return false;
+	return this->roomsNames.contains(r->name);
 }
 
 //////////////////////////////////////////////////////////////////////////////////////
