@@ -27,13 +27,20 @@ QString internetVersion;
 /**
 FET version
 */
-const QString FET_VERSION="5.2.13";
+const QString FET_VERSION="5.4.5";
+
+const int NUMBER_OF_LANGUAGES=12;
 
 /**
 FET language
 */
 QString FET_LANGUAGE="en_GB";
 
+/**
+Timetable html css javaScript Level, by Volker Dirr
+*/
+int TIMETABLE_HTML_LEVEL;
+
 QString protect(const QString& str) //used for xml
 {
 	QString p=str;
@@ -90,6 +97,7 @@ QString protect2id(const QString& str) //used for html
 	p.replace("<", "&lt;");
 	//p.replace("'", "&apos;");
 	p.replace(" ", "_");		// id must be a single token
+	p.replace(",", "_");		// looks like this makes trouble
 	return p;
 }
 
