@@ -50,20 +50,28 @@ The language
 */
 extern QString FET_LANGUAGE;
 
+//English has to be counted also
+extern const int NUMBER_OF_LANGUAGES;
+
+/**
+Timetable html css javaScript Level, added by Volker Dirr
+*/
+extern int TIMETABLE_HTML_LEVEL;
+
 /**
 The maximum number of different years of students
 */
-const int MAX_YEARS=100;
+const int MAX_YEARS=500;
 
 /**
 Maximum number of allowed groups per year of students
 */
-const int MAX_GROUPS_PER_YEAR=100;
+const int MAX_GROUPS_PER_YEAR=500;
 
 /**
 Maximum number of allowed subgroups per group of students
 */
-const int MAX_SUBGROUPS_PER_GROUP=100;
+const int MAX_SUBGROUPS_PER_GROUP=500;
 
 /**
 The maximum total number of different groups of students
