@@ -79,11 +79,14 @@ public slots:
 	void on_dataTimeConstraintsActivitiesSameStartingHourAction_activated();
 	void on_dataTimeConstraintsActivitiesNotOverlappingAction_activated();
 	void on_dataTimeConstraintsMinNDaysBetweenActivitiesAction_activated();
+	void on_dataTimeConstraintsActivityEndsStudentsDayAction_activated();
 
 	void on_dataTimeConstraintsTeacherNotAvailableAction_activated();
 	void on_dataTimeConstraintsTeacherMaxDaysPerWeekAction_activated();
 	void on_dataTimeConstraintsTeachersMaxHoursDailyAction_activated();
 	void on_dataTimeConstraintsTeacherMaxHoursDailyAction_activated();
+	void on_dataTimeConstraintsTeachersMinHoursDailyAction_activated();
+	void on_dataTimeConstraintsTeacherMinHoursDailyAction_activated();
 	void on_dataTimeConstraintsTeachersMaxGapsPerWeekAction_activated();
 	void on_dataTimeConstraintsTeacherMaxGapsPerWeekAction_activated();
 
@@ -120,8 +123,13 @@ public slots:
 	void on_languageGermanAction_activated();
 	void on_languageHungarianAction_activated();
 	void on_languageMacedonianAction_activated();
+	void on_languageSpanishAction_activated();
 	
 	void on_checkForUpdatesAction_toggled();
+
+	void on_settingsRestoreDefaultsAction_activated();
+
+	void on_settingsTimetableHtmlLevelAction_activated();
 	
 	void httpDone(bool error);
 	
