@@ -62,6 +62,9 @@ extern QString conflictsString;
 
 time_t start_time;
 
+extern int permutation[MAX_ACTIVITIES];
+int savedPermutation[MAX_ACTIVITIES];
+
 void GenerateMultipleThread::run()
 {
 	genMulti.abortOptimization=false;
@@ -71,9 +74,11 @@ void GenerateMultipleThread::run()
 	
 		bool impossible;
 		bool timeExceeded;
-		bool ok=genMulti.precompute(); //here I can speed up, precomputation is only needed to restore permutation of activities
-		assert(ok);
-		//cout<<"timeLimit=="<<timeLimit<<endl;
+		
+		//bool ok=genMulti.precompute(); //here I can speed up, precomputation is only needed to restore permutation of activities
+		//assert(ok);
+		for(int qq=0; qq<gt.rules.nInternalActivities; qq++)
+			permutation[qq]=savedPermutation[qq];
 
 		genMulti.generate(timeLimit, impossible, timeExceeded);
 
@@ -176,8 +181,9 @@ void TimetableGenerateMultipleForm::start(){
 	QString s2=INPUT_FILENAME_XML.right(INPUT_FILENAME_XML.length()-INPUT_FILENAME_XML.findRev(FILE_SEP)-1);
 	QString destDir=OUTPUT_DIR+FILE_SEP+s2;
 	if(dir.exists(destDir)){
-		QMessageBox::warning(this, tr("FET information"), tr("Cannot proceeed, directory %1 exists and might not be empty,"
-		 " (it might contain old files). You need to manually remove all contents of this directory AND the directory itself (or rename it)")
+		QMessageBox::warning(this, tr("FET information"), tr("Directory %1 exists and might not be empty,"
+		 " (it might contain old files). You need to manually remove all contents of this directory AND the directory itself (or rename it)"
+		 " and then you can generate multiple timetables")
 		 .arg(destDir));
 		 
 		return;
@@ -202,7 +208,6 @@ void TimetableGenerateMultipleForm::start(){
 	//currentResultsTextEdit->repaint();
 
 	bool ok=genMulti.precompute();
-
 	if(!ok){
 		currentResultsTextEdit->setText(TimetableGenerateMultipleForm::tr("Cannot optimize - please modify your data"));
 		currentResultsTextEdit->repaint();
@@ -222,6 +227,9 @@ void TimetableGenerateMultipleForm::start(){
 
 	simulation_running_multi=true;
 
+	for(int qq=0; qq<gt.rules.nInternalActivities; qq++)
+		savedPermutation[qq]=permutation[qq];
+
 	generateMultipleThread.start();
 }
 
@@ -259,19 +267,19 @@ void TimetableGenerateMultipleForm::timetableGenerated(int timetable, const QStr
 void TimetableGenerateMultipleForm::stop()
 {
 	if(!simulation_running_multi){
-		QMessageBox::critical(this, TimetableGenerateMultipleForm::tr("FET information"),
+		/*QMessageBox::critical(this, TimetableGenerateMultipleForm::tr("FET information"),
 		 TimetableGenerateMultipleForm::tr("Simulation stopped but the simulation is not running."
-		 " This should not happen. Maybe you aborted simulation previously. Please report possible bug to author"));
+		 " This should not happen. Maybe you aborted simulation previously. Please report possible bug to author"));*/
 
 		return;
 	}
 
+	simulation_running_multi=false;
+
 	mutex.lock();
 	genMulti.abortOptimization=true;
 	mutex.unlock();
 
-	simulation_running_multi=false;
-
 	QString s=TimetableGenerateMultipleForm::tr("Simulation interrupted.");
 	s+=" ";
 
@@ -298,14 +306,14 @@ void TimetableGenerateMultipleForm::finished()
 void TimetableGenerateMultipleForm::simulationFinished()
 {
 	if(!simulation_running_multi){
-		QMessageBox::critical(this, TimetableGenerateMultipleForm::tr("FET information"),
+		/*QMessageBox::critical(this, TimetableGenerateMultipleForm::tr("FET information"),
 		 TimetableGenerateMultipleForm::tr("Simulation finished but the simulation is not running."
-		 " This should not happen. Maybe you aborted simulation previously. Please report possible bug to author"));
+		 " This should not happen. Maybe you aborted simulation previously. Please report possible bug to author"));*/
 
 		return;
 	}
 
-	assert(simulation_running_multi);
+	simulation_running_multi=false;
 
 	QString s2=INPUT_FILENAME_XML.right(INPUT_FILENAME_XML.length()-INPUT_FILENAME_XML.findRev(FILE_SEP)-1);
 	QString destDir=OUTPUT_DIR+FILE_SEP+s2;
@@ -314,8 +322,6 @@ void TimetableGenerateMultipleForm::simulationFinished()
 		TimetableGenerateMultipleForm::tr("Simulation terminated successfully. The results are saved in directory %1 in html"
 		" and xml mode and the soft conflicts in txt mode.").arg(destDir));
 
-	simulation_running_multi=false;
-
 	startPushButton->setEnabled(TRUE);
 	stopPushButton->setDisabled(TRUE);
 	minutesGroupBox->setEnabled(TRUE);
